==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-taskbar/translations/taskbar_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>RazorTaskButton</name>
    <message>
        <location filename="../razortaskbutton.cpp" line="360"/>
        <source>Application</source>
        <translation>应用程序</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="393"/>
        <source>To &amp;Desktop</source>
        <translation>到&amp;桌面</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="395"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;全部桌面</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="402"/>
        <source>Desktop &amp;%1</source>
        <translation>桌面 &amp;%1</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="409"/>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;到当前桌面</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="438"/>
        <source>&amp;Restore</source>
        <translation>&amp;恢复</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="442"/>
        <source>Mi&amp;nimize</source>
        <translation>最&amp;小化</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="418"/>
        <source>Ma&amp;ximize</source>
        <translation>最&amp;大化</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="427"/>
        <source>Maximize vertically</source>
        <translation>垂直最大化</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="432"/>
        <source>Maximize horizontally</source>
        <translation>水平最大化</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="448"/>
        <source>Roll down</source>
        <translation>卷下</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="454"/>
        <source>Roll up</source>
        <translation>卷上</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="463"/>
        <source>&amp;Layer</source>
        <translation>&amp;层</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="465"/>
        <source>Always on &amp;top</source>
        <translation>总在&amp;顶层</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="470"/>
        <source>&amp;Normal</source>
        <translation>&amp;正常</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="475"/>
        <source>Always on &amp;bottom</source>
        <translation>总在&amp;底层</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="483"/>
        <source>&amp;Close</source>
        <translation>&amp;关闭</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="14"/>
        <source>Razor Task Manager Settings</source>
        <translation>Razor任务管理器设置</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="20"/>
        <source>Window List Content</source>
        <translation>窗口列表内容</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="26"/>
        <source>Show windows from current desktop</source>
        <translation>显示当前桌面的窗口</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="29"/>
        <location filename="../razortaskbarconfiguration.ui" line="39"/>
        <source>wlcB</source>
        <translation>wlcB</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="36"/>
        <source>Show windows from all desktops</source>
        <translation>显示所有桌面的窗口</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="49"/>
        <source>Window List Appearance</source>
        <translation>窗口列表外观</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="55"/>
        <source>Button style</source>
        <translation>按钮样式</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="65"/>
        <source>Max button width</source>
        <translation>最大按钮宽度</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="41"/>
        <source>Icon and text</source>
        <translation>图标和文字</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="42"/>
        <source>Only icon</source>
        <translation>仅图标</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="43"/>
        <source>Only text</source>
        <translation>仅文字</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-taskbar/translations/taskbar_zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.0">
<context>
    <name>RazorTaskButton</name>
    <message>
        <source>Application</source>
        <translation>应用程序</translation>
    </message>
    <message>
        <source>To &amp;Desktop</source>
        <translation>到&amp;桌面</translation>
    </message>
    <message>
        <source>&amp;All Desktops</source>
        <translation>&amp;全部桌面</translation>
    </message>
    <message>
        <source>Desktop &amp;%1</source>
        <translation>桌面 &amp;%1</translation>
    </message>
    <message>
        <source>&amp;To Current Desktop</source>
        <translation>&amp;到当前桌面</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>最&amp;大化</translation>
    </message>
    <message>
        <source>Maximize vertically</source>
        <translation>垂直最大化</translation>
    </message>
    <message>
        <source>Maximize horizontally</source>
        <translation>水平最大化</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;恢复</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>最&amp;小化</translation>
    </message>
    <message>
        <source>Roll down</source>
        <translation>卷下</translation>
    </message>
    <message>
        <source>Roll up</source>
        <translation>卷上</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation>&amp;层</translation>
    </message>
    <message>
        <source>Always on &amp;top</source>
        <translation>总在&amp;顶层</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;正常</translation>
    </message>
    <message>
        <source>Always on &amp;bottom</source>
        <translation>总在&amp;底层</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;关闭</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <source>Razor Task Manager Settings</source>
        <translation>Razor任务管理器设置</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation>窗口列表内容</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation>显示当前桌面的窗口</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation>显示所有桌面的窗口</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation>窗口列表外观</translation>
    </message>
    <message>
        <source>Button style</source>
        <translation>按钮样式</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation>最大按钮宽度</translation>
    </message>
    <message>
        <source>Close on middle-click</source>
        <translation>鼠标中击时关闭</translation>
    </message>
    <message>
        <source>Icon and text</source>
        <translation>图标和文字</translation>
    </message>
    <message>
        <source>Only icon</source>
        <translation>仅图标</translation>
    </message>
    <message>
        <source>Only text</source>
        <translation>仅文字</translation>
    </message>
</context>
</TS>
